@@ -740,12 +740,13 @@ END
 
 my $get_ec2_api=sub {
 
+   package get_ec2_api;
    print "\n";
    my ($hash,$output,$error)=('','','');
    ($hash,$output,$error)=Net::FullAuto::Cloud::fa_amazon::run_aws_cmd(
       "aws iam list-access-keys");
    Net::FullAuto::FA_Core::handle_error($error) if $error;
-   $configure_aws1->()
+   $Net::FullAuto::Cloud::fa_amazon::configure_aws1->()
       if (-1<index $output,'configure credentials') ||
       (-1<index $output,'Partial credentials found');
    my $choose_demo_banner=<<'END';
